/* This file is part of tagr.
   Copyright (C) 2000, 2005,  Max Bouglacoff, Sergey Poznyakoff

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
   02111-1307, USA. */
/* $Id: log.c,v 1.1.1.1.2.1 2005/11/22 11:39:07 gray Exp $ */

#ifdef HAVE_CONFIG_H
# include <config.h>
#endif

#include <stdlib.h>
#include <stdio.h>
#include <stdarg.h>
#include <string.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <errno.h>
#include <syslog.h>
#include <tagr.h>

char *progname;
int use_stderr = 1;

void
init_syslog (char *name)
{
  progname = name;
  openlog (progname, LOG_PID, LOGFACILITY);
}

int syslog_level[] = {
  LOG_DEBUG,
  LOG_INFO,
  LOG_NOTICE,
  LOG_WARNING,
  LOG_ERR,
  LOG_CRIT,
};

char *level_str[] = {
  "debug",
  "info",
  "notice",
  "warning",
  "error",
  "CRITICAL",
};


void
logmsg (int level, const char *fmt, ...)
{
  va_list ap;

  va_start (ap, fmt);
  if (use_stderr)
    {
      fprintf (stderr, "%s: %s: ", progname, level_str[level]);
      vfprintf (stderr, fmt, ap);
      fprintf (stderr, "\n");
    }
  vsyslog (syslog_level[level], fmt, ap);
  va_end (ap);
}

void
die (int code, const char *fmt, ...)
{
  va_list ap;

  va_start (ap, fmt);
  fprintf (stderr, "%s: ", progname);
  vfprintf (stderr, fmt, ap);
  fprintf (stderr, "\n");
  va_end (ap);
  exit (code);
}
